"""
********************************************************************************
 * @file    airflow_api.py
 * @author  Kevin Bazurto
 * @date    04/05/2022
 * @brief   Library to interact with Airflow through a REST API
 *  
 *******************************************************************************
 *     EXTERNAL FUNCTIONS
 *******************************************************************************
 * __init__(ip_address, user_name, password) - Class Constructor
 * get_active_dags() - Returns List of active DAGs
 *******************************************************************************
"""

import requests
from requests.auth import HTTPBasicAuth


class AirflowAPI:

    def __init__(self, ip_address, user_name, password):
        """
        Class Constructor
        
        Args:
            ip_address: String: Airflow's ip address
            user_name: String: Airflow's username
            password: String: Username's password
            
        Return:
            None        
        """
        
        self._url = f"http://{ip_address}/api/v1/dags"
        self._user_name = user_name
        self._password = password 

    def get_active_dags(self):
        """
        Get a list of active DAGs
        
        Args:
            None
            
        Returns:
            List[String...]
            
        Raises:
            Exception: An error ocurred while sending request to API
        """
    
        try:
            authetication = HTTPBasicAuth(self._user_name, self._password)
            response = requests.get(self._url, verify=False, auth=authetication)
        except Exception as e:
            raise Exception("Something went wrong, please check your class " \
                    "constructor and try again, error message: {}".format(e))
        
        #Check for active dags
        active = []
        for each in response.json().get('dags'):
            if each.get("is_paused") == False:
                active.append(each.get("dag_id"))
                
        return active